import { ApolloClient, InMemoryCache } from "@apollo/client";
import { prepareRoutes } from "@curi/router";
import { omit } from 'ramda';
import React from 'react';
import { CreateProjectInput, Project } from './generated/graphql';
import { ProjectDetail, ProjectEditor, PROJECT } from "./projects";

export default prepareRoutes([
  {
    name: "dashboard",
    path: "",
    respond() {
      return { body: () => <div>DashBoard</div> };
    },
  },
  {
    name: "create-project",
    path: "projects/create",
    respond({ resolved }) {
      const input: CreateProjectInput = {
        name: "",
        comment: "",
        webHookSecret: "",
        sshUrl: "",
        webUrl: "",
      };
      return { body: () => <ProjectEditor project={input} /> };
    },
  },
  {
    name: "edit-project",
    path: "projects/:projectId/edit",
    async resolve(
      matched,
      { client }: { client: ApolloClient<InMemoryCache> }
    ) {
      const { data } = await client.query<{ project: Project }>({
        query: PROJECT,
        variables: { id: matched?.params.projectId },
      });
      return {
        body: () => (
          <ProjectEditor project={omit(["__typename"], data.project)} />
        ),
      };
    },
    respond({ resolved }) {
      return resolved;
    },
  },
  {
    name: "project-detail",
    path: "projects/:projectId",
    async resolve(
      matched,
      { client }: { client: ApolloClient<InMemoryCache> }
    ) {
      const { data } = await client.query<{ project: Project }>({
        query: PROJECT,
        variables: { id: matched?.params.projectId },
      });
      return {
        body: () => (
          <ProjectDetail project={omit(["__typename"], data.project)} />
        ),
      };
    },
    respond({ resolved }) {
      return resolved;
    },
  },
]);
